@@ -9,23 +9,34 @@
 #
 from __future__ import absolute_import, division, unicode_literals
 
+
 from uuid import uuid4
 
-from mo_imports import export
-
 from jx_base.expressions import jx_expression
-from jx_base.facts import Facts
-from jx_base.namespace import Namespace
-from jx_base.schema import Schema
-from jx_base.snowflake import Snowflake
-from jx_base.table import Table
-from jx_python.expressions import Literal, Python
+from jx_base.models.container import Container
+from jx_base.models.container import Container
+from jx_base.models.facts import Facts
+from jx_base.models.namespace import Namespace
+from jx_base.models.nested_path import NestedPath
+from jx_base.models.relation import Relation
+from jx_base.models.schema import Schema
+from jx_base.models.snowflake import Snowflake
+from jx_base.models.table import Table
+from jx_python.expressions import Python
 from mo_dots import coalesce, listwrap, to_data
 from mo_dots.datas import register_data
 from mo_dots.lists import last
 from mo_future import is_text, text
-from mo_json import value2json, true, false, null, EXISTS, OBJECT, NESTED
-from mo_json.typed_encoder import EXISTS_TYPE
+from mo_imports import export
+from mo_json import (
+    value2json,
+    true,
+    false,
+    null,
+    EXISTS,
+    OBJECT,
+    ARRAY, )
+from mo_json.typed_encoder import EXISTS_KEY
 from mo_logs import Log
 from mo_logs.strings import expand_template, quote
 
@@ -33,7 +44,8 @@ ENABLE_CONSTRAINTS = True
 
 
 def generateGuid():
-    """Gets a random GUID.
+    """
+    Gets a random GUID.
     Note: python's UUID generation library is used here.
     Basically UUID is the same as GUID when represented as a string.
     :Returns:
@@ -52,19 +64,38 @@ def _exec(code, name):
         globs = globals()
         fake_locals = {}
         exec(code, globs, fake_locals)
-        temp = globs[name] = fake_locals[name]
+        temp = fake_locals[name]
         return temp
-    except Exception as e:
-        Log.error("Can not make class\n{{code}}", code=code, cause=e)
+    except Exception as cause:
+        Log.error("Can not make class\n{{code}}", code=code, cause=cause)
 
 
 _ = listwrap, last, true, false, null
 
 
+def _to_python(value):
+    return value2json(value)
+
+
+def failure(row, rownum, rows, constraint):
+    constraint = to_data(constraint)
+    if constraint['and']:
+        for a in constraint['and']:
+            failure(row, rownum, rows, a)
+        return
+    expr = jx_expression(constraint)
+
+    try:
+        if not expr(row, rownum, row):
+            raise Log.error("{{row}} fails to pass {{req}}", row=row, req=expr.__data__())
+    except Exception as cause:
+        raise Log.error("{{row}} fails to pass {{req}}", row=row, req=expr.__data__(), cause=cause)
+
+
 def DataClass(name, columns, constraint=None):
     """
     Use the DataClass to define a class, but with some extra features:
-    1. restrict the datatype of property
+    1. restrict the data type of property
     2. restrict if `required`, or if `nulls` are allowed
     3. generic constraints on object properties
 
@@ -78,20 +109,18 @@ def DataClass(name, columns, constraint=None):
             "required", - False if it must be defined (even if None)
             "nulls",    - True if property can be None, or missing
             "default",  - A default value, if none is provided
-            "type"      - a Python datatype
+            "type"      - a Python data type
         }
     :param constraint: a JSON query Expression for extra constraints (return true if all constraints are met)
     :return: The class that has been created
     """
 
-    columns = to_data(
-        [
-            {"name": c, "required": True, "nulls": False, "type": object}
-            if is_text(c)
-            else c
-            for c in columns
-        ]
-    )
+    columns = to_data([
+        {"name": c, "required": True, "nulls": False, "type": object}
+        if is_text(c)
+        else c
+        for c in columns
+    ])
     constraint = {
         "and": [
             {"exists": c.name} for c in columns if not c.nulls and c.default == None
@@ -102,13 +131,14 @@ def DataClass(name, columns, constraint=None):
     required = to_data(filter(lambda c: c.required and c.default == None, columns)).name
     # nulls = to_data(filter(lambda c: c.nulls, columns)).name
     defaults = {c.name: coalesce(c.default, None) for c in columns}
-    types = {c.name: coalesce(c.jx_type, object) for c in columns}
+    types = {c.name: coalesce(c.type, object) for c in columns}
 
     code = expand_template(
         """
-from __future__ import unicode_literals
-from mo_future import is_text, is_binary
-from collections import Mapping
+import re
+from mo_future import is_text, is_binary, Mapping
+from mo_dots import Null
+from jx_base import failure
 
 meta = None
 types_ = {{types}}
@@ -120,12 +150,14 @@ class {{class_name}}(Mapping):
 
     def _constraint(row, rownum, rows):
         code = {{constraint_expr|quote}}
+        import re
         if {{constraint_expr}}:
             return
+        failure(row, rownum, rows, {{constraint}})
         Log.error(
             "constraint\\n{" + "{code}}\\nnot satisfied {" + "{expect}}\\n{" + "{value|indent}}",
-            code={{constraint_expr|quote}}, 
-            expect={{constraint}}, 
+            code={{constraint_expr|quote}},
+            expect={{constraint}},
             value=row
         )
 
@@ -170,10 +202,13 @@ class {{class_name}}(Mapping):
         return object.__hash__(self)
 
     def __eq__(self, other):
-        if isinstance(other, {{class_name}}) and dict(self)==dict(other) and self is not other:
-            Log.error("expecting to be same object")
-        return self is other
-
+        try:
+            if isinstance(other, {{class_name}}) and dict(self)==dict(other) and self is not other:
+                Log.error("expecting to be same object")
+            return self is other
+        except Exception:
+            return False
+            
     def __dict__(self):
         return {k: getattr(self, k) for k in {{slots}}}
 
@@ -198,20 +233,20 @@ class {{class_name}}(Mapping):
 """,
         {
             "class_name": name,
-            "slots": "(" + (", ".join(quote(s) for s in slots)) + ")",
-            "required": "{" + (", ".join(quote(s) for s in required)) + "}",
-            "defaults": Literal(defaults).to_python(),
+            "slots": "(" + ", ".join(quote(s) for s in slots) + ")",
+            "required": "{" + ", ".join(quote(s) for s in required) + "}",
+            "defaults": _to_python(defaults),
             "len_slots": len(slots),
-            "dict": "{" + (", ".join(quote(s) + ": self." + s for s in slots)) + "}",
+            "dict": "{" + ", ".join(quote(s) + ": self." + s for s in slots) + "}",
             "assign": "; ".join(
                 "_set(output, " + quote(s) + ", self." + s + ")" for s in slots
             ),
             "types": "{"
-            + (",".join(quote(k) + ": " + v.__name__ for k, v in types.items()))
+            + ",".join(quote(k) + ": " + v.__name__ for k, v in types.items())
             + "}",
-            "constraint_expr": Python[
-                jx_expression(not ENABLE_CONSTRAINTS or constraint)
-            ].to_python(),
+            "constraint_expr": jx_expression(
+                not ENABLE_CONSTRAINTS or constraint
+            ).partial_eval(Python).to_python(),
             "constraint": value2json(constraint),
         },
     )
@@ -223,13 +258,16 @@ class {{class_name}}(Mapping):
 
 TableDesc = DataClass(
     "Table",
-    ["name", {"name": "url", "nulls": true}, "query_path", {"name": "last_updated", "nulls": False}, "columns"],
-    constraint={"and": [{"eq": [{"last": "query_path"}, {"literal": "."}]}]},
+    [
+        "name",
+        {"name": "url", "nulls": true},
+        "query_path",
+        {"name": "last_updated", "nulls": False},
+        "columns",
+    ],
+    constraint={"and": [{"ne": [{"last": "query_path"}, {"literal": "."}]}]},
 )
 
-
-from jx_base.container import Container
-
 Column = DataClass(
     "Column",
     [
@@ -237,8 +275,7 @@ Column = DataClass(
         "es_column",
         "es_index",
         "es_type",
-        "jx_type",
-        {"name": "useSource", "default": False},
+        "json_type",
         "nested_path",  # AN ARRAY OF PATHS (FROM DEEPEST TO SHALLOWEST) INDICATING THE JSON SUB-ARRAYS
         {"name": "count", "nulls": True},
         {"name": "cardinality", "nulls": True},
@@ -246,57 +283,70 @@ Column = DataClass(
         {"name": "partitions", "nulls": True},
         "last_updated",
     ],
-    constraint={
-        "and": [
-            {
-                "when": {"ne": {"name": "."}},
-                "then": {"ne": ["name", {"first": "nested_path"}]},
-                "else": True,
-            },
-            {"not": {"find": {"es_column": "null"}}},
-            {"not": {"eq": {"es_column": "string"}}},
-            {"not": {"eq": {"es_type": "object", "jx_type": "exists"}}},
-            {
-                "when": {"suffix": {"es_column": "." + EXISTS_TYPE}},
-                "then": {"eq": {"jx_type": EXISTS}},
-                "else": True,
-            },
-            {
-                "when": {"suffix": {"es_column": "." + EXISTS_TYPE}},
-                "then": {"exists": "cardinality"},
-                "else": True,
-            },
-            {
-                "when": {"eq": {"jx_type": OBJECT}},
-                "then": {"in": {"cardinality": [0, 1]}},
-                "else": True,
-            },
-            {
-                "when": {"eq": {"jx_type": NESTED}},
-                "then": {"in": {"cardinality": [0, 1]}},
-                "else": True,
-            },
-            {"eq": [{"last": "nested_path"}, {"literal": "."}]},
-            {
-                "when": {"eq": [{"literal": ".~N~"}, {"right": {"es_column": 4}}]},
-                "then": {
-                    "and": [
-                        {"gt": {"multi": 1}},
-                        {"eq": {"jx_type": "nested"}},
-                        {"eq": {"es_type": "nested"}},
-                    ]
-                },
-                "else": True,
-            },
-            {
-                "when": {"gte": [{"count": "nested_path"}, 2]},
-                "then": {
-                    "ne": [{"first": {"right": {"nested_path": 2}}}, {"literal": "."}]
-                },  # SECOND-LAST ELEMENT
-                "else": True,
-            },
-        ]
-    },
+    constraint={"and": [
+        {
+            "when": {"ne": {"name": "."}},
+            "then": {"or": [
+                {"and": [{"eq": {"json_type": "object"}}, {"eq": {"multi": 1}}]},
+                {"ne": ["name", {"first": "nested_path"}]},
+            ]},
+            "else": True,
+        },
+        {
+            "when": {"eq": {"es_column": "."}},
+            "then": {"in": {"json_type": ["nested", "object"]}},
+            "else": True,
+        },
+        {"not": {"find": {"es_column": "null"}}},
+        {"not": {"eq": {"es_column": "string"}}},
+        {"not": {"eq": {"es_type": "object", "json_type": "exists"}}},
+        {
+            "when": {"suffix": {"es_column": "." + EXISTS_KEY}},
+            "then": {"eq": {"json_type": EXISTS}},
+            "else": True,
+        },
+        {
+            "when": {"suffix": {"es_column": "." + EXISTS_KEY}},
+            "then": {"exists": "cardinality"},
+            "else": True,
+        },
+        {
+            "when": {"eq": {"json_type": OBJECT}},
+            "then": {"in": {"cardinality": [0, 1]}},
+            "else": True,
+        },
+        {
+            "when": {"eq": {"json_type": ARRAY}},
+            "then": {"in": {"cardinality": [0, 1]}},
+            "else": True,
+        },
+        {"not": {"prefix": [{"first": "nested_path"}, {"literal": "testdata"}]}},
+        {"ne": [{"last": "nested_path"}, {"literal": "."}]},  # NESTED PATHS MUST BE REAL TABLE NAMES INSIDE Namespace
+        {
+            "when": {"eq": [{"literal": ".~N~"}, {"right": {"es_column": 4}}]},
+            "then": {"or": [
+                {"and": [
+                    {"gt": {"multi": 1}},
+                    {"eq": {"json_type": "nested"}},
+                    {"eq": {"es_type": "nested"}},
+                ]},
+                {"and": [
+                    {"eq": {"multi": 1}},
+                    {"eq": {"json_type": "object"}},
+                    {"eq": {"es_type": "object"}},
+                ]},
+            ]},
+            "else": True,
+        },
+        {
+            "when": {"gte": [{"count": "nested_path"}, 2]},
+            "then": {"ne": [
+                {"first": {"right": {"nested_path": 2}}},
+                {"literal": "."},
+            ]},  # SECOND-LAST ELEMENT
+            "else": True,
+        },
+    ]},
 )
 
 export("jx_base.expressions.query_op", Column)
