@@ -11,21 +11,21 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions.literal import Literal
-from mo_dots import coalesce, Null, is_data
+from mo_dots import coalesce, is_data
 from mo_imports import export
-from mo_json import NUMBER
+from mo_json.types import T_TIME
 from mo_times.dates import Date
 
 
 class DateOp(Literal):
-    date_type = NUMBER
+    date_type = T_TIME
 
     def __new__(cls, *args, **kwargs):
         return object.__new__(cls)
 
-    def __init__(self, term):
+    def __init__(self, *term):
         if is_data(term):
-            term = term['date']  # FOR WHEN WE MIGHT DO Literal({"date":term})
+            term = term["date"]  # FOR WHEN WE MIGHT DO Literal({"date":term})
         self.date = term
         Literal.__init__(self, float(Date(self.date)))
 
@@ -42,5 +42,9 @@ class DateOp(Literal):
     def __call__(self, row=None, rownum=None, rows=None):
         return Date(self.date)
 
+    @property
+    def type(self):
+        return self.date_type
+
 
 export("jx_base.expressions.literal", DateOp)
