@@ -10,40 +10,43 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import simplified, TRUE
+from jx_base.expressions._utils import TRUE
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.false_op import FALSE
 from mo_imports import expect
-from mo_json import BOOLEAN
+from mo_json.types import T_BOOLEAN
 
 NotOp = expect("NotOp")
 
 
 class ExistsOp(Expression):
-    data_type = BOOLEAN
+    _data_type = T_BOOLEAN
 
     def __init__(self, term):
-        Expression.__init__(self, [term])
+        Expression.__init__(self, term)
         self.expr = term
 
     def __data__(self):
         return {"exists": self.expr.__data__()}
 
+    def __call__(self, row, rownum=None, rows=None):
+        value = self.expr(row, rownum, rows)
+        return value != None and value != ""
+
     def vars(self):
         return self.expr.vars()
 
     def map(self, map_):
-        return self.lang[ExistsOp(self.expr.map(map_))]
+        return ExistsOp(self.expr.map(map_))
 
-    def missing(self):
+    def missing(self, lang):
         return FALSE
 
-    def invert(self):
-        return self.lang[self.expr].missing()
+    def invert(self, lang):
+        return self.expr.missing(lang)
 
     def exists(self):
         return TRUE
 
-    @simplified
-    def partial_eval(self):
-        return self.lang[NotOp(self.expr.missing())].partial_eval()
+    def partial_eval(self, lang):
+        return (NotOp(self.expr.missing(lang))).partial_eval(lang)
