@@ -10,7 +10,6 @@
 
 from __future__ import absolute_import, division, unicode_literals
 
-from jx_base.expressions._utils import simplified
 from jx_base.expressions.basic_substring_op import BasicSubstringOp
 from jx_base.expressions.expression import Expression
 from jx_base.expressions.length_op import LengthOp
@@ -24,15 +23,15 @@ from jx_base.expressions.variable import Variable
 from jx_base.expressions.when_op import WhenOp
 from jx_base.language import is_op
 from mo_dots import is_data
-from mo_json import STRING
+from mo_json.types import T_TEXT
 
 
 class NotRightOp(Expression):
     has_simple_form = True
-    data_type = STRING
+    _data_type = T_TEXT
 
-    def __init__(self, term):
-        Expression.__init__(self, term)
+    def __init__(self, *term):
+        Expression.__init__(self, *term)
         if is_data(term):
             self.value, self.length = term.items()[0]
         else:
@@ -48,25 +47,22 @@ class NotRightOp(Expression):
         return self.value.vars() | self.length.vars()
 
     def map(self, map_):
-        return self.lang[NotRightOp([self.value.map(map_), self.length.map(map_)])]
+        return NotRightOp(self.value.map(map_), self.length.map(map_))
 
-    def missing(self):
-        return self.lang[OrOp([self.value.missing(), self.length.missing()])]
+    def missing(self, lang):
+        return OrOp(self.value.missing(lang), self.length.missing(lang))
 
-    @simplified
-    def partial_eval(self):
-        value = self.lang[self.value].partial_eval()
-        length = self.length.partial_eval()
+    def partial_eval(self, lang):
+        value = (self.value).partial_eval(lang)
+        length = self.length.partial_eval(lang)
 
         if length is ZERO:
             return value
 
         max_length = LengthOp(value)
         part = BasicSubstringOp(
-            [
-                value,
-                ZERO,
-                MaxOp([ZERO, MinOp([max_length, SubOp([max_length, length])])]),
-            ]
+            value,
+            ZERO,
+            MaxOp(ZERO, MinOp(max_length, SubOp(max_length, length))),
         )
-        return self.lang[WhenOp(self.missing(), **{"else": part})].partial_eval()
+        return (WhenOp(self.missing(lang), **{"else": part})).partial_eval(lang)
