@@ -10,13 +10,7 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import BetweenOp as BetweenOp_
-from jx_python.expressions._utils import Python
 
 
 class BetweenOp(BetweenOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        return (
-            Python[self.value].to_python()
-            + " in "
-            + Python[self.superset].to_python(many=True)
-        )
+    pass
