@@ -10,13 +10,12 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import CountOp as CountOp_
-from jx_python.expressions._utils import Python
 
 
 class CountOp(CountOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
+    def to_python(self):
         return (
             "sum(((0 if v==None else 1) for v in "
-            + Python[self.terms].to_python(not_null=False, boolean=False, many=True)
+            + self.terms.to_python()
             + "), 0)"
         )
