@@ -10,10 +10,9 @@
 from __future__ import absolute_import, division, unicode_literals
 
 from jx_base.expressions import LengthOp as LengthOp_
-from jx_python.expressions._utils import Python
 
 
 class LengthOp(LengthOp_):
-    def to_python(self, not_null=False, boolean=False, many=False):
-        value = Python[self.term].to_python()
+    def to_python(self):
+        value = self.term.to_python()
         return "len(" + value + ") if (" + value + ") != None else None"
