@@ -37,7 +37,6 @@ class AggregationFunction(object):
         """
         raise NotImplementedError
 
-
     def merge(self, agg):
         """
         ADD TWO AGGREGATES TOGETHER
@@ -73,6 +72,7 @@ class One(AggregationFunction):
     """
     EXPECTING ONLY ONE VALUE OVER THE RESULT SET
     """
+
     def __init__(self, **kwargs):
         object.__init__(self)
         self.value = None
@@ -84,14 +84,22 @@ class One(AggregationFunction):
             self.value = value
             return
         if value != self.value:
-            Log.error("Expecting value to match: {{expecting}}, {{instead}}",  expecting= self.value,  instead= value)
+            Log.error(
+                "Expecting value to match: {{expecting}}, {{instead}}",
+                expecting=self.value,
+                instead=value,
+            )
 
     def merge(self, agg):
         if self.value is None and agg.value is not None:
             self.value = agg.value
         elif self.value is not None:
             if self.value != agg.value:
-                Log.error("Expecting value to match: {{expecting}}, {{instead}}",  expecting= self.value,  instead= agg.value)
+                Log.error(
+                    "Expecting value to match: {{expecting}}, {{instead}}",
+                    expecting=self.value,
+                    instead=agg.value,
+                )
 
     def end(self):
         return self.value
@@ -104,7 +112,6 @@ class WindowFunction(AggregationFunction):
         """
         raise NotImplementedError
 
-
     def sub(self, value):
         """
         REMOVE value FROM AGGREGATE
@@ -146,7 +153,9 @@ class _Stats(WindowFunction):
         ignore = mo_math.ceiling(len(self.samples) * (1 - self.middle) / 2)
         if ignore * 2 >= len(self.samples):
             return stats.Stats()
-        output = stats.Stats(samples=sorted(self.samples)[ignore:len(self.samples) - ignore:])
+        output = stats.Stats(samples=sorted(self.samples)[
+            ignore : len(self.samples) - ignore :
+        ])
         output.samples = list(self.samples)
         return output
 
@@ -182,7 +191,6 @@ class Min(WindowFunction):
         object.__init__(self)
         self.total = Multiset()
 
-
     def add(self, value):
         if value == None:
 
@@ -223,7 +231,6 @@ class Max(WindowFunction):
         object.__init__(self)
         self.max = None
 
-
     def add(self, value):
         self.max = mo_math.MAX([self.max, value])
 
@@ -239,7 +246,6 @@ class Count(WindowFunction):
         object.__init__(self)
         self.total = 0
 
-
     def add(self, value):
         if value == None:
             return
@@ -259,7 +265,6 @@ class Sum(WindowFunction):
         object.__init__(self)
         self.total = 0
 
-
     def add(self, value):
         if value == None:
             return
@@ -283,7 +288,6 @@ class Percentile(WindowFunction):
         self.percentile = percentile
         self.total = []
 
-
     def add(self, value):
         if value == None:
             return
@@ -294,7 +298,7 @@ class Percentile(WindowFunction):
             return
         try:
             i = self.total.index(value)
-            self.total = self.total[:i] + self.total[i+1:]
+            self.total = self.total[:i] + self.total[i + 1 :]
         except Exception as e:
             Log.error("Problem with window function", e)
 
@@ -322,7 +326,8 @@ class List(WindowFunction):
 def median(*args, **kwargs):
     return Percentile(0.5, *args, **kwargs)
 
-name2accumulator = {
+
+name_to_aggregate = {
     "count": Count,
     "sum": Sum,
     "exists": Exists,
@@ -333,5 +338,5 @@ name2accumulator = {
     "minimum": Min,
     "median": median,
     "percentile": Percentile,
-    "one": One
+    "one": One,
 }
